@@ -105,8 +105,6 @@
 
 ;;;; Variables and options
 
-(defconst erc-backend-version "$Revision: 1.44.2.1 $")
-
 (defvar erc-server-responses (make-hash-table :test #'equal)
   "Hashtable mapping server responses to their handler hooks.")
 
@@ -314,13 +312,7 @@ alist."
   :type '(repeat (cons (string :tag "Target")
                        coding-system)))
 
-(defcustom erc-server-connect-function
-  (if (and (fboundp 'open-network-stream-nowait)
-           ;; CVS Emacs claims to define open-network-stream-nowait on
-           ;; windows, however, it does, in fact, not work.
-           (not (memq system-type '(windows-nt cygwin ms-dos darwin))))
-      'open-network-stream-nowait
-    'open-network-stream)
+(defcustom erc-server-connect-function 'open-network-stream
   "Function used to initiate a connection.
 It should take same arguments as `open-network-stream' does."
   :group 'erc-server
@@ -571,7 +563,12 @@ action."
   "Return the coding system or cons cell appropriate for TARGET.
 This is determined via `erc-encoding-coding-alist' or
 `erc-server-coding-system'."
-  (or (cdr (assoc target erc-encoding-coding-alist))
+  (or (when target
+        (let ((case-fold-search t))
+          (catch 'match
+            (dolist (pat erc-encoding-coding-alist)
+              (when (string-match (car pat) target)
+                (throw 'match (cdr pat)))))))
       (and (functionp erc-server-coding-system)
            (funcall erc-server-coding-system))
       erc-server-coding-system))
@@ -764,10 +761,10 @@ PROCs `process-buffer' is `current-buffer' when this function is called."
                 (substring string 1 posn)))
 
         (setf (erc-response.command msg)
-              (let* ((bposn (string-match "[^ ]" string posn))
+              (let* ((bposn (string-match "[^ \n]" string posn))
                      (eposn (string-match " " string bposn)))
                 (setq posn (and eposn
-                                (string-match "[^ ]" string eposn)))
+                                (string-match "[^ \n]" string eposn)))
                 (substring string bposn eposn)))
 
         (while (and posn
@@ -775,7 +772,7 @@ PROCs `process-buffer' is `current-buffer' when this function is called."
           (push (let* ((bposn posn)
                        (eposn (string-match " " string bposn)))
                   (setq posn (and eposn
-                                  (string-match "[^ ]" string eposn)))
+                                  (string-match "[^ \n]" string eposn)))
                   (substring string bposn eposn))
                 (erc-response.command-args msg)))
         (when posn
@@ -857,8 +854,10 @@ Finds hooks by looking in the `erc-server-responses' hashtable."
   (let ((hook (or (erc-get-hook (erc-response.command message))
                   'erc-default-server-functions)))
     (run-hook-with-args-until-success hook process message)
-    (with-current-buffer (erc-server-buffer)
-      (run-hook-with-args 'erc-timer-hook (erc-current-time)))))
+    (let ((server-buffer (erc-server-buffer)))
+      (when (buffer-live-p server-buffer)
+        (with-current-buffer server-buffer
+          (run-hook-with-args 'erc-timer-hook (erc-current-time)))))))
 
 (add-hook 'erc-default-server-functions 'erc-handle-unknown-server-response)
 
