@@ -1,24 +1,26 @@
 ;;; erc-bbdb.el --- Integrating the BBDB into ERC
 
-;; Copyright (C) 2001,2002,2004,2005 Free Software Foundation, Inc.
+;; Copyright (C) 2001, 2002, 2004, 2005 Free Software Foundation, Inc.
 
 ;; Author: Andreas Fuchs <asf@void.at>
 ;; Maintainer: Mario Lang <mlang@delysid.org>
 
-;; This is free software; you can redistribute it and/or modify it
-;; under the terms of the GNU General Public License as published by
+;; This file is part of GNU Emacs.
+
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
 ;; the Free Software Foundation; either version 2, or (at your option)
 ;; any later version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
-;; License for more details.
-;;
+
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING. If not, write to the
-;; Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-;; Boston, MA 02110-1301 USA
+;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -48,9 +50,6 @@
 (require 'bbdb-gui)
 (require 'bbdb-hooks)
 
-(defconst erc-bbdb-version "$Revision: 1.31 $"
-  "ERC BBDB revision.")
-
 (defgroup erc-bbdb nil
   "Variables related to BBDB usage."
   :group 'erc)
@@ -111,6 +110,11 @@ their \"displayed name\"."
   :group 'erc-bbdb
   :type 'boolean)
 
+(defcustom erc-bbdb-electric-p nil
+  "*If t, BBDB popup buffer is electric."
+  :group 'erc-bbdb
+  :type 'boolean)
+
 (defun erc-bbdb-search-name-and-create (create-p name nick finger-host silent)
   (let* ((ircnick (cons erc-bbdb-irc-nick-field (concat "^"
 							(regexp-quote nick))))
@@ -131,7 +135,8 @@ their \"displayed name\"."
       record)))
 
 (defun erc-bbdb-show-entry (record channel proc)
-  (let ((bbdb-display-layout (bbdb-grovel-elide-arg erc-bbdb-elide-display)))
+  (let ((bbdb-display-layout (bbdb-grovel-elide-arg erc-bbdb-elide-display))
+	(bbdb-electric-p erc-bbdb-electric-p))
     (when (and record (or (eq erc-bbdb-popup-type t)
 			  (and (eq erc-bbdb-popup-type 'visible)
 			       (and channel
@@ -246,3 +251,5 @@ counterparts `erc-pals', `erc-dangerous-hosts' and `erc-fools'."
 ;; indent-tabs-mode: t
 ;; tab-width: 8
 ;; End:
+
+;; arch-tag: 1edf3729-cd49-47dc-aced-70fcfc28c815
