@@ -1,25 +1,26 @@
 ;;; erc-complete.el --- Provides Nick name completion for ERC
 
-;; Copyright (C) 2001, 2002  Alex Schroeder
+;; Copyright (C) 2001, 2002, 2004 Free Software Foundation, Inc.
 
 ;; Author: Alex Schroeder <alex@gnu.org>
 ;; URL: http://www.emacswiki.org/cgi-bin/wiki.pl?ErcCompletion
 
-;; This file is not part of GNU Emacs.
+;; This file is part of GNU Emacs.
 
-;; This program is free software; you can redistribute it and/or modify
+;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2 of the License, or
-;; (at your option) any later version.
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
 
-;; This program is distributed in the hope that it will be useful,
+;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -28,7 +29,7 @@
 ;; pcomplete.  There is no autoload cookie in this file.  If you want
 ;; to use the code in this file, add the following to your ~/.emacs:
 
-;; (autoload 'erc-complete "erc-complete" "Complete nick at point." t) 
+;; (autoload 'erc-complete "erc-complete" "Complete nick at point." t)
 
 ;;; Code:
 
@@ -36,9 +37,7 @@
 (require 'erc-match); for erc-pals
 (require 'hippie-exp); for the hippie expand stuff
 
-(defconst erc-complete-version "$Revision: 1.11 $"
-  "ERC complete revision.")
-
+;;;###autoload
 (defun erc-complete ()
   "Complete nick at point.
 See `erc-try-complete-nick' for more technical info.
@@ -47,6 +46,10 @@ This function is obsolete, use `erc-pcomplete' instead."
   (let ((hippie-expand-try-functions-list '(erc-try-complete-nick)))
     (hippie-expand nil)))
 
+(defgroup erc-old-complete nil
+  "Nick completion.  Obsolete, use erc-pcomplete instead."
+  :group 'erc)
+
 (defcustom erc-nick-completion 'all
   "Determine how the list of nicks is determined during nick completion.
 See `erc-complete-nick' for information on how to activate this.
@@ -64,14 +67,14 @@ or you may use an arbitrary lisp expression."
 		 (repeat :tag "List" (string :tag "Nick"))
 		 function
 		 sexp)
-  :group 'erc)
+  :group 'erc-old-complete)
 
 (defcustom erc-nick-completion-ignore-case t
   "*Non-nil means don't consider case significant in nick completion.
 Case will be automatically corrected when non-nil.
 For instance if you type \"dely TAB\" the word completes and changes to
 \"delYsid\"."
-  :group 'erc
+  :group 'erc-old-complete
   :type 'boolean)
 
 (defun erc-nick-completion-exclude-myself ()
@@ -81,14 +84,14 @@ This function returns a list of all the members in the channel, except
 your own nick.  This way if you're named foo and someone is called foobar,
 typing \"f o TAB\" will directly give you foobar.  Use this with
 `erc-nick-completion'."
-  (delete
+  (remove
    (erc-current-nick)
-   (mapcar (function car) channel-members)))
+   (erc-get-channel-nickname-list)))
 
 (defcustom erc-nick-completion-postfix ": "
   "*When `erc-complete' is used in the first word after the prompt,
 add this string when a unique expansion was found."
-  :group 'erc
+  :group 'erc-old-complete
   :type 'string)
 
 (defun erc-command-list ()
@@ -107,7 +110,7 @@ The type of completion depends on `erc-nick-completion'."
 	 (try-complete-erc-nick old erc-pals))
 	((eq erc-nick-completion 'all)
 	 (try-complete-erc-nick old (append
-				     (mapcar (function car) channel-members)
+				     (erc-get-channel-nickname-list)
 				     (erc-command-list))))
 	((functionp erc-nick-completion)
 	 (try-complete-erc-nick old (funcall erc-nick-completion)))
@@ -209,3 +212,10 @@ Window configurations are stored in
 (provide 'erc-complete)
 
 ;;; erc-complete.el ends here
+;;
+;; Local Variables:
+;; indent-tabs-mode: t
+;; tab-width: 8
+;; End:
+
+;; arch-tag: 3be13ee8-8fdb-41ab-83c2-6582c757b91e
