@@ -1,28 +1,30 @@
 ;; erc-replace.el -- wash and massage messages inserted into the buffer
 
+;; Copyright (C) 2001, 2002, 2004 Free Software Foundation, Inc.
+
 ;; Author: Andreas Fuchs <asf@void.at>
 ;; Maintainer: Mario Lang (mlang@delysid.org)
 ;; Keywords: IRC, client, Internet
 ;; URL: http://www.emacswiki.org/cgi-bin/wiki.pl?ErcReplace
 
-;; Copyright (C) 2001  Andreas Fuchs <asf@void.at>
-;; Copyright (C) 2002  Alex Schroeder <alex@gnu.org>
+;; This file is part of GNU Emacs.
 
-;; This program is free software; you can redistribute it and/or modify
+;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2 of the License, or
-;; (at your option) any later version.
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
 
-;; This program is distributed in the hope that it will be useful,
+;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;; Commentary:
+;;; Commentary:
 
 ;; This module allows you to systematically replace text in incoming
 ;; messages.  Load erc-replace, and customize `erc-replace-alist'.
@@ -31,12 +33,13 @@
 ;; (require 'erc-replace)
 ;; (erc-replace-mode 1)
 
-;; Code:
+;;; Code:
 
 (require 'erc)
 
-(defconst erc-replace-version "$Revision: 1.4 $"
-  "Revision of the ERC replace module.")
+(defgroup erc-replace nil
+  "Replace text from incoming messages"
+  :group 'erc)
 
 (defcustom erc-replace-alist nil
   "Alist describing text to be replaced in incoming messages.
@@ -47,7 +50,7 @@ expression or a variable, or any sexp, TO can be a string or a
 function to call, or any sexp.  If a function, it will be called with
 one argument, the string to be replaced, and it should return a
 replacement string."
-  :group 'erc
+  :group 'erc-replace
   :type '(repeat (cons :tag "Search & Replace"
 		       (choice :tag "From"
 			       regexp
@@ -86,4 +89,5 @@ It replaces text according to `erc-replace-alist'."
 
 (provide 'erc-replace)
 
+;; arch-tag: dd904a59-d8a6-47f8-ac3a-76b698289a18
 ;;; erc-replace.el ends here
